From e28b41fcc6d59d1774995c5a7b6aa4c634616481 Mon Sep 17 00:00:00 2001
From: Elvis Pranskevichus <elvis@magic.io>
Date: Mon, 8 Feb 2016 15:14:58 -0500
Subject: [PATCH] brightray build fixes

---
 brightray.gyp  | 52 ++++++++++++++++++++++++++++++++++++++++++++++++----
 brightray.gypi | 20 +++++++-------------
 2 files changed, 55 insertions(+), 17 deletions(-)

diff --git a/brightray.gyp b/brightray.gyp
index 4a821d1..0897f9d 100644
--- a/brightray.gyp
+++ b/brightray.gyp
@@ -1,7 +1,7 @@
 {
   'variables': {
     # The libraries brightray will be compiled to.
-    'linux_system_libraries': 'gtk+-2.0 libnotify dbus-1 x11 xi xcursor xdamage xrandr xcomposite xext xfixes xrender xtst gconf-2.0 gmodule-2.0 nss'
+    'linux_system_libraries': 'gtk+-2.0 libnotify dbus-1 x11 xi xcursor xdamage xrandr xcomposite xext xfixes xrender xtst gmodule-2.0 nss'
   },
   'includes': [
     'filenames.gypi',
@@ -9,6 +9,11 @@
   'targets': [
     {
       'target_name': 'brightray',
+      'dependencies': [
+        'cups',
+        'gconf',
+        '<(libchromiumcontent_src_dir)/chromiumcontent/chromiumcontent.gyp:chromiumcontent_all'
+      ],
       'type': 'static_library',
       'include_dirs': [
         '.',
@@ -101,12 +106,9 @@
             }, {
               'link_settings': {
                 'libraries': [
-                  # Link with ffmpeg.
-                  '<(libchromiumcontent_dir)/libffmpeg.so',
                   # Following libraries are required by libchromiumcontent:
                   '-lasound',
                   '-lcap',
-                  '-lcups',
                   '-lrt',
                   '-ldl',
                   '-lresolv',
@@ -302,5 +304,47 @@
         }],  # OS=="win"
       ],
     },
+    {
+      'target_name': 'gconf',
+      'type': 'none',
+      'conditions': [
+        ['use_gconf==1 and _toolset=="target"', {
+          'direct_dependent_settings': {
+            'cflags': [
+              '<!@(<(pkg-config) --cflags gconf-2.0)',
+            ],
+            'defines': [
+              'USE_GCONF',
+            ],
+          },
+          'link_settings': {
+            'ldflags': [
+              '<!@(<(pkg-config) --libs-only-L --libs-only-other gconf-2.0)',
+            ],
+            'libraries': [
+              '<!@(<(pkg-config) --libs-only-l gconf-2.0)',
+            ],
+          },
+        }],
+      ],
+    },
+    {
+      'target_name': 'cups',
+      'type': 'none',
+      'conditions': [
+        ['use_cups==1', {
+          'direct_dependent_settings': {
+            'defines': [
+              'USE_CUPS',
+            ],
+            'link_settings': {
+              'libraries': [
+                '-lcups',
+              ],
+            },
+          },
+        }],
+      ],
+    },
   ],
 }
diff --git a/brightray.gypi b/brightray.gypi
index 8bae073..95bdfa1 100644
--- a/brightray.gypi
+++ b/brightray.gypi
@@ -1,9 +1,13 @@
 {
-  'includes': [
-    'vendor/download/libchromiumcontent/filenames.gypi',
-  ],
   'variables': {
     'libchromiumcontent_component%': 1,
+    'libchromiumcontent_src_dir': '<(DEPTH)',
+    'libchromiumcontent_shared_libraries_dir': '<(SHARED_INTERMEDIATE_DIR)',
+    'libchromiumcontent_static_libraries_dir': '<(SHARED_INTERMEDIATE_DIR)',
+    'libchromiumcontent_shared_libraries': [],
+    'libchromiumcontent_static_libraries': [],
+    'libchromiumcontent_shared_v8_libraries': [],
+    'libchromiumcontent_static_v8_libraries': [],
     'pkg-config%': 'pkg-config',
     'conditions': [
       # The "libchromiumcontent_component" is defined when calling "gyp".
@@ -259,22 +263,12 @@
         'conditions': [
           ['OS=="linux"', {
             'cflags': [
-              '-O2',
-              # Generate symbols, will be stripped later.
-              '-g',
-              # Don't emit the GCC version ident directives, they just end up
-              # in the .comment section taking up binary size.
-              '-fno-ident',
               # Put data and code in their own sections, so that unused symbols
               # can be removed at link time with --gc-sections.
               '-fdata-sections',
               '-ffunction-sections',
             ],
             'ldflags': [
-              # Specifically tell the linker to perform optimizations.
-              # See http://lwn.net/Articles/192624/ .
-              '-Wl,-O1',
-              '-Wl,--as-needed',
               '-Wl,--gc-sections',
             ],
           }],  # OS=="linux"
-- 
2.7.3

